@@ -5,10 +5,6 @@
 ##  http://twitter.com/JonathanSalwan
 ##  http://shell-storm.org/project/ROPgadget/
 ##
-##  This program is free software: you can redistribute it and/or modify
-##  it under the terms of the GNU General Public License as published by
-##  the Free Software  Foundation, either  version 3 of  the License, or
-##  (at your option) any later version.
 
 import ropgadget.args
 import ropgadget.binary
@@ -25,4 +21,4 @@ def main():
     import sys
     from   ropgadget.args import Args
     from   ropgadget.core import Core
-    sys.exit(Core(Args().getArgs()).analyze())
+    sys.exit(0 if Core(Args().getArgs()).analyze() else 1)
