@@ -5,17 +5,12 @@
 ##  http://shell-storm.org
 ##  http://twitter.com/JonathanSalwan
 ## 
-##  This program is free software: you can redistribute it and/or modify
-##  it under the terms of the GNU General Public License as published by
-##  the Free Software  Foundation, either  version 3 of  the License, or
-##  (at your option) any later version.
-##
 
 from capstone           import *
 from ropgadget.ropchain.arch.ropmakerx86   import *
 from ropgadget.ropchain.arch.ropmakerx64   import *
 
-class ROPMaker:
+class ROPMaker(object):
     def __init__(self, binary, gadgets, offset):
         self.__binary  = binary
         self.__gadgets = gadgets
